# icepap

![Pypi version][pypi]

Python module to configure, control and monitor IcePAP based systems.


## Installation

From within your favourite python environment:

```console
pip install icepap
```

## Usage

![spec in action](./demo.svg)


## Documentation

The project documentation can be found [here](https://alba-synchrotron.github.io/pyIcePAP-doc) or you can build it by executing:
```console
python setup.py build_sphinx
```

This documentation has been created by [sphinx](http://www.sphinx-doc.org/en/stable/).

## Tests

You can run tests simply with:
```console
python setup.py test
```

## Contribute

You can find how to contribute to this project on CONTRIBUTING.md file.


[pypi]: https://img.shields.io/pypi/pyversions/icepap.svg